@@ -6,7 +6,7 @@ use Catmandu::AlephX;
 use Data::Dumper;
 use open qw(:std :utf8);
 
-my $aleph = Catmandu::AlephX->new(url => "http://aleph.ugent.be/X");
+my $aleph = Catmandu::AlephX->new(url => "http://borges1.ugent.be/X");
 
 my $circstatus = $aleph->circ_status(sys_no => '001484478',library => 'rug01');
 
@@ -14,4 +14,4 @@ if($circstatus->is_success){
   print Dumper($circstatus);
 }else{
   say STDERR join('',@{$circstatus->errors});
-} 
+}
